@@ -33,7 +33,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use warnings;
 use Carp;
@@ -54,9 +54,9 @@ our %field_conf = (
     type => 'SINGLE_HASH',
     process => sub {
       my $val = shift;
-      if ($val =~ /"(.*)"\s+\[(.*)\]/) {
+      if ($val =~ /"(.*)"(?:\s+\[(.*)\])?/) {
         my $definition = $1;
-        my $dbxrefs = $2;
+        my $dbxrefs = $2 // '';
 
         my @dbxrefs =
           grep {
