@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.017'; # VERSION
+our $VERSION = '0.018'; # VERSION
 
 use Mouse;
 use Carp;
@@ -134,6 +134,10 @@ sub make_object
     croak "no argument passed to new()";
   }
 
+  if ($object->{is_obsolete} && $object->{name} && $object->{name} !~ /^obsolete/i) {
+    $object->{name} = "OBSOLETE " . $object->{id} . " " . $object->{name};
+  }
+
   if ($object->{is_relationshiptype} && $object->{name}) {
     $object->{name} =~ s/ /_/g;
   }
@@ -205,7 +209,8 @@ sub merge
     my $field_conf = $PomBase::Chobo::OntologyConf::field_conf{$name};
 
     if (defined $field_conf) {
-      if (defined $field_conf->{type} && $field_conf->{type} eq 'SINGLE') {
+      if (defined $field_conf->{type} &&
+            ($field_conf->{type} eq 'SINGLE' || $field_conf->{type} eq 'SINGLE_HASH')) {
         my $res = undef;
         if (defined $field_conf->{merge}) {
           $res = $field_conf->{merge}->($self, $other_term);
